/* beautiful-react-hooks version: 0.28.0 */
import { objectSpread2 as _objectSpread2, slicedToArray as _slicedToArray } from './_virtual/_rollupPluginBabelHelpers.js';
import { useRef, useState, useCallback, useEffect } from 'react';
import usePreviousValue from './usePreviousValue.js';

var defaultOptions = {
  cancelOnUnmount: true,
  cancelOnConditionChange: true
};

var useConditionalTimeout = function useConditionalTimeout(fn, milliseconds, condition) {
  var options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : defaultOptions;

  var opts = _objectSpread2(_objectSpread2({}, defaultOptions), options || {});

  var timeout = useRef();
  var callback = useRef(fn);
  var prevCondition = usePreviousValue(condition);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      isCleared = _useState2[0],
      setIsCleared = _useState2[1];

  var clear = useCallback(function () {
    if (timeout.current) {
      clearTimeout(timeout.current);
      setIsCleared(true);
    }
  }, []);
  useEffect(function () {
    if (typeof fn === 'function') {
      callback.current = fn;
    }
  }, [fn]);
  useEffect(function () {
    if (condition && typeof milliseconds === 'number') {
      timeout.current = setTimeout(function () {
        callback.current();
      }, milliseconds);
    }

    return clear;
  }, [condition, milliseconds]);
  useEffect(function () {
    if (prevCondition && condition !== prevCondition && opts.cancelOnConditionChange) {
      clear();
    }
  }, [condition, options]);
  useEffect(function () {
    return function () {
      if (opts.cancelOnUnmount) {
        clear();
      }
    };
  }, []);
  return [isCleared, clear];
};

export default useConditionalTimeout;
