/* beautiful-react-hooks version: 0.28.0 */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _rollupPluginBabelHelpers = require('./_virtual/_rollupPluginBabelHelpers.js');
var react = require('react');
var isClient = require('./utils/isClient.js');
var isAPISupported = require('./utils/isAPISupported.js');

var errorMessage = 'matchMedia is not supported, this could happen both because window.matchMedia is not supported by' + ' your current browser or you\'re using the useMediaQuery hook whilst server side rendering.';

var useMediaQuery = function useMediaQuery(mediaQuery) {
  if (!isClient.default || !isAPISupported.default('matchMedia')) {
    console.warn(errorMessage);
    return null;
  }

  var _useState = react.useState(!!window.matchMedia(mediaQuery).matches),
      _useState2 = _rollupPluginBabelHelpers.slicedToArray(_useState, 2),
      isVerified = _useState2[0],
      setIsVerified = _useState2[1];

  react.useEffect(function () {
    var mediaQueryList = window.matchMedia(mediaQuery);

    var documentChangeHandler = function documentChangeHandler() {
      return setIsVerified(!!mediaQueryList.matches);
    };

    mediaQueryList.addListener(documentChangeHandler);
    documentChangeHandler();
    return function () {
      mediaQueryList.removeListener(documentChangeHandler);
    };
  }, [mediaQuery]);
  return isVerified;
};

exports.default = useMediaQuery;
